@@ -1,9 +1,10 @@
 import sys
 from bisect import insort
 from dataclasses import dataclass
+from itertools import compress, chain
 from threading import Thread
 from types import SimpleNamespace
-from typing import Hashable, List, Set
+from typing import Hashable, List, Set, Collection, Union
 
 import numpy as np
 from networkx import Graph, connected_components, incidence_matrix
@@ -14,7 +15,7 @@ from respice.collections import OneToManyInvertibleMapping
 from respice.components import Component, CurrentBranch, VoltageBranch, SwitchBranch
 from respice.itertools.custom import compact, uncompact
 from respice.math import flcm
-from respice.math.optimization.rootsolvers.overshoot import solve
+from respice.math.optimization.rootsolvers.mixed import solve
 from respice.threading import prefer_thread_yield
 from .MNAEquationStack import MNAEquationStack
 from .TransientEFMSimulation import TransientEFMSimulation
@@ -44,6 +45,10 @@ class _MergedNode:
     nodes: Set[Hashable]
 
 
+class ConvergenceError(Exception):
+    pass
+
+
 class Circuit:
     _EVENT_RESAMPLING_PRECISION = sys.float_info.epsilon * 2**20
     _CIRCUIT_SWITCH_CONFIGURATION_CACHE_SIZE = 2 ** 16
@@ -213,7 +218,12 @@ class Circuit:
                 # Convert old result/guess to new guess.
                 x0 = eq2.assemble_vector(*eq1.disassemble_vector(x0))
 
-            return solve(eq2.lambdify(), x0, args=(t1, t2), jac=eq2.lambdify_jacobian()).x
+            result = solve(eq2.lambdify(), x0, args=(t1, t2), jac=eq2.lambdify_jacobian())
+
+            if result.success:
+                return result.x
+            else:
+                raise ConvergenceError(result)
 
         def get_equation(t):
             switch_config = tuple(switch.switch_state(t) for switch in self._get_switches())
@@ -229,7 +239,14 @@ class Circuit:
                     gnd_nodes = set()
 
                 switch_configured_graph = create_switch_configured_graph(switch_config)
-                equation = MNAEquationStack(switch_configured_graph, self._component_branches.values(), gnd_nodes)
+
+                equation = MNAEquationStack(
+                    switch_configured_graph,
+                    ([branch
+                      for branch in coupled_branches
+                      if not isinstance(branch, SwitchBranch)]
+                     for coupled_branches in self._component_branches.values()),
+                    gnd_nodes)
                 self._cache.circuit_switch_configurations[switch_config] = switch_configured_graph, equation
 
             return switch_config, switch_configured_graph, equation
@@ -286,7 +303,14 @@ class Circuit:
                         # Use the incidence matrix to solve for any kind of switch layout.
                         # If especially switches are connected to other switches, with the help of the
                         # incidence matrix it is possible to solve for all currents through those switches.
-                        merged_graph = self._graph.subgraph(node.nodes)
+                        merged_graph = self._graph.subgraph(node.nodes).copy()
+
+                        # Sometimes other branches than switches can form self loops if they are connected between
+                        # the switches of the same merged node. In this case we need to exclude those from the
+                        # incidence matrix.
+                        merged_graph.remove_edges_from({branch
+                                                        for _, _, branch in merged_graph.edges
+                                                        if not isinstance(branch, SwitchBranch)})
 
                         nodes = list(merged_graph.nodes)[:-1]
 
@@ -340,7 +364,9 @@ class Circuit:
         # in this regard).
         for event in get_events(np.nextafter(t1 - self._EVENT_RESAMPLING_PRECISION, np.inf),
                                 np.nextafter(t1 + self._EVENT_RESAMPLING_PRECISION, -np.inf),  # This is not a typo, it is t1.
-                                lambda _: constant_interpolation(result1)):
+                                lambda component: constant_interpolation(
+                                    self._get_coupled_vi_vector(component, result1, eq1)
+                                )):
             insort(ts, event + self._EVENT_RESAMPLING_PRECISION)
 
         t2 = next(titer)
@@ -614,7 +640,7 @@ class Circuit:
                               t0: float,
                               *Ts: float,
                               fast_steps: int = 10,
-                              subdivisions: int = 8,
+                              subdivisions: Union[int, Collection] = 8,
                               periodicity_tolerance: float = 2**-26) -> TransientSteadyStateEFMSimulation:
         """
         Finds the periodic steady-state solution of the circuit using the envelope-following-method (EFM) for
@@ -650,11 +676,15 @@ class Circuit:
         :param subdivisions:
             How many steps shall be simulated via EFM inside the slow-rate interval.
             Effectively determines the skip intervals for the EFM.
+
+            * If of type `int`: Divides the fundamental period time equally.
+            * If of type `typing.Collection`: Relative time points to place into the fundamental period time.
+              Elements must be of type `float`.
         :param periodicity_tolerance
             A rounding tolerance to apply to the fundamental period times to obtain the overall
             covering fundamental frequency. The smaller this value, the rougher the simulation
             might estimate the whole steady state solution, but if too high insignificant floating
-            point number precision may be cought up and lead to an extreme overall fundamental
+            point number precision may be caught up and lead to an extreme overall fundamental
             period time and again reduce simulation precision because for a longer fundamental
             frequency more subdivisions should be made over the interval to get a fairly correct
             solution.
@@ -665,15 +695,23 @@ class Circuit:
             A simulation object containing the steady-state solution.
             Note that computation happens *asynchronously*!
         """
-        if subdivisions < 0:
-            raise ValueError('parameter subdivisions must be 0 or greater')
-
         T_slow = flcm(*Ts, tol=periodicity_tolerance, ignore_zeros=True)
         T_fast = min(Ts)
 
         # Quantization step to find properly aligned intervals / skips that can be used for EF-method.
-        subdivisions = min(subdivisions, T_slow // T_fast - 2)  # To avoid duplicate time steps.
-        skips = np.diff(np.floor(np.linspace(0, T_slow // T_fast - 1, subdivisions + 2)).astype(int)) - 1
+        if isinstance(subdivisions, int):
+            if subdivisions < 0:
+                raise ValueError('parameter subdivisions must be 0 or greater')
+
+            discrete_subdivisions = np.linspace(0, T_slow // T_fast - 1, subdivisions + 2)
+        elif isinstance(subdivisions, Collection):
+            discrete_subdivisions = np.sort(np.fromiter(chain((s for s in subdivisions if 0.0 <= s <= 1.0), [0.0, 1.0]),
+                                                        dtype=float)) * (T_slow // T_fast - 1)
+        else:
+            raise TypeError()
+
+        interval_diffs = np.diff(np.floor(discrete_subdivisions).astype(int))
+        skips = np.fromiter(compress(interval_diffs, interval_diffs > 0), dtype=int) - 1
 
         simulation = TransientSteadyStateEFMSimulation(skips, self._component_branches, self._graph.nodes)
 
