@@ -368,10 +368,14 @@ class MNAEquationStack:
                 source, target = self._graph.get_nodes(branch)
 
                 coupled_val = ''
-                if target in self._nodes:
-                    coupled_val += f'v_i[{self._nodes.index(target)}]'
-                if source in self._nodes:
-                    coupled_val += f'-v_i[{self._nodes.index(source)}]'
+                if source is target:
+                    # Coupling that self-closes on a ground node might end up here.
+                    coupled_val = '0'
+                else:
+                    if target in self._nodes:
+                        coupled_val += f'v_i[{self._nodes.index(target)}]'
+                    if source in self._nodes:
+                        coupled_val += f'-v_i[{self._nodes.index(source)}]'
             else:
                 raise AssertionError(f'Unknown branch type encountered: {type(branch)}')
 
@@ -539,7 +543,7 @@ class MNAEquationStack:
                         else:
                             raise AssertionError(f'Unknown branch type encountered: {type(branch)}')
                 elif isinstance(term, KirchhoffEquationBranchConsecutiveTerm):
-                    jacobi_vector[self._currents.index(term.branch) + len(self._nodes)].append('1')
+                    jacobi_vector[self._currents.index(term.branch) + len(self._nodes)].append('-1' if term.negative else '1')
                 else:
                     raise AssertionError(f'Invalid term type encountered: {type(term)}')
 
