@@ -1,6 +1,6 @@
 from itertools import chain
 from threading import RLock, Event
-from typing import Iterable, List, Hashable, Tuple, Union, Collection
+from typing import Iterable, List, Hashable, Tuple, Union, Collection, Optional
 
 import numpy as np
 
@@ -155,17 +155,19 @@ class TransientEFMSimulation:
         """
         return self._aborted.is_set()
 
-    def wait(self, timeout: float = None):
+    def wait(self, timeout: Optional[float] = None, throw: bool = True) -> bool:
         """
         Wait for the simulation to finish.
 
         :param timeout:
             Timeout to wait. If `None`, blocks infinitely until result is ready.
+        :param throw:
+            Whether exceptions from the computation thread are thrown in the calling thread.
         :return:
             `True` if the result is ready, `False` if not. Only meaningful when a timeout is given.
         """
         finished = self._finished.wait(timeout)
-        if self._aborted.is_set():
+        if throw and self._aborted.is_set():
             raise self._exception
         return finished
 
@@ -188,9 +190,13 @@ class TransientEFMSimulation:
 
             linear_ramp = (distributed_ts - ts1[-1]) / (ts2[0] - ts1[-1])
 
+            # Normalized voltages with the slope of the envelope taken into account to avoid jumps in the interpolation.
+            nvs1 = vs1 - np.interp(ts1, [ts1[0], ts1[-1]], [vs1[0] - vs1[-1], 0])
+            nvs2 = vs2 - np.interp(ts2, [ts2[0], ts2[-1]], [0, vs2[-1] - vs2[0]])
+
             interpolated_vs.extend(
-                np.tile(np.interp(merged_relative_ts, ts1 - ts1[0], vs1), ss) * (1 - linear_ramp) +
-                np.tile(np.interp(merged_relative_ts, ts2 - ts2[0], vs2), ss) * linear_ramp
+                np.tile(np.interp(merged_relative_ts, ts1 - ts1[0], nvs1), ss) * (1 - linear_ramp) +
+                np.tile(np.interp(merged_relative_ts, ts2 - ts2[0], nvs2), ss) * linear_ramp
             )
 
             # Also append the real result to interpolation.
@@ -603,7 +609,7 @@ class TransientEFMSimulation:
         """
         return np.fromiter(flatten(self.get_interval_switch_states(switch)), dtype=bool)
 
-    def plot(self, *entities: Union[Component, Branch], features: Collection[str] = 'vip'):
+    def plot(self, *entities: Union[Component, Branch], features: Collection[str] = 'vip', throw: bool = True):
         """
         Plots the result.
 
@@ -621,11 +627,14 @@ class TransientEFMSimulation:
             * v: voltage plot
             * i: current plot
             * p: power plot
+        :param throw:
+            Whether exceptions from the computation thread are thrown in the calling thread.
+            Set it to `False` if you also want to print partial results.
         """
         if not features:
             raise ValueError('no features specified')
 
-        self.wait()
+        self.wait(throw=throw)
 
         # Determine necessary components and respective branches to plot.
         if entities:
@@ -747,7 +756,7 @@ class TransientEFMSimulation:
         """
         self.wait()
 
-        data = [('t', self._tss)]
+        data = [('t', self.get_timesteps())]
 
         # Additionally iterating over components sorts branches by component,
         # thus makes it easier for humans to read.
