@@ -9,7 +9,7 @@ class CurrentSourceAC(PeriodicCurrentSource):
     """
     An AC current supply.
 
-    You might alternatively set the current amplitude by specifying an effective voltage.
+    You might alternatively set the current amplitude by specifying an effective current.
     Be sure to assign to the property `effective_amplitude` after initialization.
 
     amplitude:
@@ -19,23 +19,25 @@ class CurrentSourceAC(PeriodicCurrentSource):
 
     @property
     def effective_amplitude(self):
-        """
+        r"""
         The effective amplitude (:math:`A_{RMS}`) is easily derived
         according to the formula for RMS (see https://en.wikipedia.org/wiki/Root_mean_square and
         https://en.wikipedia.org/wiki/RMS_amplitude)
 
-        .. math:
+        .. math::
+
              A_{RMS} &= \sqrt{\frac{1}{T} \int_{0}^{T}{f^2(t) dt}} \\
                      &= A \cdot
                         \sqrt{
                             \frac{1}{2 \pi}
                                 \left (
-                                    \int_{0}^{T}{\sin^2{(\varphi)} d\varphi}
+                                    \int_{0}^{T}{\sin^2{(t)} dt}
                                 \right )
                             } \\
                      &= A / \sqrt{2}
+
         :return:
-            The effective amplitude current (measured in Amperes).
+            The effective current (measured in Amperes).
         """
         return self.amplitude / sqrt(2)
 
@@ -46,13 +48,14 @@ class CurrentSourceAC(PeriodicCurrentSource):
 
         This function just multiplies the given value with sqrt(2).
 
-        .. math:
+        .. math::
+
              A = \sqrt{2} \cdot A_{RMS}
 
         :param value:
-            The effective amplitude value.
+            The effective value.
         """
         self.amplitude = value * sqrt(2)
 
-    def get_signal(self, phase):
+    def get_signal(self, phase: float) -> float:
         return self.amplitude * sin(phase)
