@@ -1,6 +1,5 @@
-from math import exp
-
 from dataclasses import dataclass
+from math import exp
 
 from .TwoTerminalCurrentComponent import TwoTerminalCurrentComponent
 
@@ -18,8 +17,8 @@ class ShockleyDiode(TwoTerminalCurrentComponent):
     i_s:
         Reverse bias saturation current (also known as leakage current).
         Depending on the material used, common values are
-        - silicon diodes: usually between 10^-12 A and 10^-10 A (1uA to 100uA).
-        - germanium diodes: about 10^-4 A (0.1mA)
+        * silicon diodes: usually between 10^-12 A and 10^-10 A (1uA to 100uA).
+        * germanium diodes: about 10^-4 A (0.1mA)
     v_t:
         Thermal voltage V_T. For approximate room temperate 300K this value
         is 25.85mV (0.02585V). This is default.
